@@ -15,15 +15,13 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GTKHTML_PRIVATE_H
 #define _GTKHTML_PRIVATE_H
 
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
 #include <gtk/gtkimcontext.h>
 #include <gtk/gtkwidget.h>
 #include "gtkhtml-types.h"
@@ -47,8 +45,6 @@ struct _GtkHTMLPrivate {
 
 	GtkWidget *search_input_line;
 
-	GnomePrintJob *print_master;
-
 	guint notify_spell_id;
 	guint notify_monospace_font_id;
 
