@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 
    Author: Ettore Perazzoli <ettore@helixcode.com>
 */
@@ -70,6 +70,10 @@ gboolean    html_cursor_up                      (HTMLCursor *cursor,
 						 HTMLEngine *engine);
 gboolean    html_cursor_down                    (HTMLCursor *cursor,
 						 HTMLEngine *engine);
+gboolean    html_cursor_left                    (HTMLCursor *cursor,
+						 HTMLEngine *engine);
+gboolean    html_cursor_right                   (HTMLCursor *cursor,
+						 HTMLEngine *engine);
 void        html_cursor_beginning_of_document   (HTMLCursor *cursor,
 						 HTMLEngine *engine);
 void        html_cursor_end_of_document         (HTMLCursor *cursor,
