@@ -15,8 +15,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLIFRAME_H_
@@ -65,6 +65,11 @@ HTMLObject *   html_iframe_new                   (GtkWidget *parent,
 						  gboolean border);
 
 void           html_iframe_set_scrolling         (HTMLIFrame *iframe, GtkPolicyType scroll);
+
+void           html_iframe_set_margin_width      (HTMLIFrame *iframe,
+						 gint margin);
+void           html_iframe_set_margin_height     (HTMLIFrame *iframe,
+						 gint margin);
 						  
 #endif
 
